#[non_exhaustive]pub enum ValidationState {
Unspecified,
Valid,
Invalid,
UnknownValue(UnknownValue),
}Expand description
A contact’s validation state indicates whether or not it is the correct contact to be receiving notifications for a particular resource.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
The validation state is unknown or unspecified.
Valid
The contact is marked as valid. This is usually done manually by the contact admin. All new contacts begin in the valid state.
Invalid
The contact is considered invalid. This may become the state if the contact’s email is found to be unreachable.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using ValidationState::value or ValidationState::name.
Implementations