#[non_exhaustive]pub struct ComputeContactsRequest {
pub parent: String,
pub notification_categories: Vec<NotificationCategory>,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request message for the ComputeContacts method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The name of the resource to compute contacts for. Format: organizations/{organization_id}, folders/{folder_id} or projects/{project_id}
notification_categories: Vec<NotificationCategory>The categories of notifications to compute contacts for. If ALL is included in this list, contacts subscribed to any notification category will be returned.
page_size: i32Optional. The maximum number of results to return from this request.
Non-positive values are ignored. The presence of next_page_token in the
response indicates that more results might be available.
If not specified, the default page_size is 100.
page_token: StringOptional. If present, retrieves the next batch of results from the
preceding call to this method. page_token must be the value of
next_page_token from the previous response. The values of other method
parameters should be identical to those in the previous call.
Implementations
Sourceimpl ComputeContactsRequest
impl ComputeContactsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_notification_categories<T, V>(self, v: T) -> Self
pub fn set_notification_categories<T, V>(self, v: T) -> Self
Sets the value of notification_categories.
Example
use google_cloud_essentialcontacts_v1::model::NotificationCategory;
let x = ComputeContactsRequest::new().set_notification_categories([
NotificationCategory::All,
NotificationCategory::Suspension,
NotificationCategory::Security,
]);Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ComputeContactsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ComputeContactsRequest
impl Clone for ComputeContactsRequest
Sourcefn clone(&self) -> ComputeContactsRequest
fn clone(&self) -> ComputeContactsRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more