#[non_exhaustive]pub struct ComputeContactsResponse {
pub contacts: Vec<Contact>,
pub next_page_token: String,
/* private fields */
}Expand description
Response message for the ComputeContacts method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.contacts: Vec<Contact>All contacts for the resource that are subscribed to the specified notification categories, including contacts inherited from any parent resources.
next_page_token: StringIf there are more results than those appearing in this response, then
next_page_token is included. To get the next set of results, call this
method again using the value of next_page_token as page_token and the
rest of the parameters the same as the original request.
Implementations
Sourceimpl ComputeContactsResponse
impl ComputeContactsResponse
pub fn new() -> Self
Sourcepub fn set_contacts<T, V>(self, v: T) -> Self
pub fn set_contacts<T, V>(self, v: T) -> Self
Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ComputeContactsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ComputeContactsResponse
impl Clone for ComputeContactsResponse
Sourcefn clone(&self) -> ComputeContactsResponse
fn clone(&self) -> ComputeContactsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ComputeContactsResponse
impl Debug for ComputeContactsResponse
Sourceimpl Default for ComputeContactsResponse
impl Default for ComputeContactsResponse
Sourcefn default() -> ComputeContactsResponse
fn default() -> ComputeContactsResponse
Returns the “default value” for a type. Read more
Sourceimpl Message for ComputeContactsResponse
impl Message for ComputeContactsResponse
Sourceimpl PartialEq for ComputeContactsResponse
impl PartialEq for ComputeContactsResponse
impl StructuralPartialEq for ComputeContactsResponse