#[non_exhaustive]pub struct ListContactsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request message for the ListContacts method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent resource name. Format: organizations/{organization_id}, folders/{folder_id} or projects/{project_id}
page_size: i32Optional. The maximum number of results to return from this request.
Non-positive values are ignored. The presence of next_page_token in the
response indicates that more results might be available.
If not specified, the default page_size is 100.
page_token: StringOptional. If present, retrieves the next batch of results from the
preceding call to this method. page_token must be the value of
next_page_token from the previous response. The values of other method
parameters should be identical to those in the previous call.
Implementations
Sourceimpl ListContactsRequest
impl ListContactsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListContactsRequest::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListContactsRequest
impl Clone for ListContactsRequest
Sourcefn clone(&self) -> ListContactsRequest
fn clone(&self) -> ListContactsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListContactsRequest
impl Debug for ListContactsRequest
Sourceimpl Default for ListContactsRequest
impl Default for ListContactsRequest
Sourcefn default() -> ListContactsRequest
fn default() -> ListContactsRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ListContactsRequest
impl Message for ListContactsRequest
Sourceimpl PartialEq for ListContactsRequest
impl PartialEq for ListContactsRequest
impl StructuralPartialEq for ListContactsRequest